==> openj9-18_0.33.1.orig.tar.xz: src-openj9-18-0.33.1/openj9/jcl/src/java.base/share/classes/jdk/internal/ref/CleanerShutdown.java <==
/*[INCLUDE-IF Sidecar19-SE]*/
/*******************************************************************************
 * Copyright (c) 2016, 2020 IBM Corp. and others
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution and
 * is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] http://openjdk.java.net/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
 *******************************************************************************/
package jdk.internal.ref;

import jdk.internal.ref.CleanerFactory;

import java.lang.ref.Cleaner;
import java.lang.ref.Cleaner.Cleanable;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.security.AccessController;
import java.security.PrivilegedAction;

@SuppressWarnings("javadoc")
public class CleanerShutdown {
	
	public static void shutdownCleaner() {
		Cleaner commonCleaner = CleanerFactory.cleaner();
		CleanerImpl commonCleanerImpl = CleanerImpl.getCleanerImpl(commonCleaner);
		Cleanable ref = null;

		while ((ref = (Cleanable) commonCleanerImpl.queue.poll()) != null) {
			try {
				ref.clean();
			} catch (Throwable t) {
				/* do nothing */
			}
		}
		
		try {
			Method phantomRemove = PhantomCleanable.class.getDeclaredMethod("remove", (Class<?>[]) null); //$NON-NLS-1$
			AccessController.doPrivileged((PrivilegedAction<Void>) () -> {
				phantomRemove.setAccessible(true);
				return null;
			});
			while(!commonCleanerImpl.phantomCleanableList.isListEmpty()) {
				phantomRemove.invoke(commonCleanerImpl.phantomCleanableList, (Object[]) null);
			}
		} catch (NoSuchMethodException
				| SecurityException
				| IllegalAccessException
				| IllegalArgumentException
				| InvocationTargetException e)
		{
			/* should not fail */
			e.printStackTrace();
		}
	}
}

==> openj9-21_0.56.0.orig.tar.xz: src-openj9-21-0.56.0/openj9/jcl/src/java.base/share/classes/jdk/internal/ref/CleanerShutdown.java <==
/*[INCLUDE-IF JAVA_SPEC_VERSION >= 9]*/
/*
 * Copyright IBM Corp. and others 2016
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution and
 * is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package jdk.internal.ref;

import java.lang.ref.Cleaner;
import java.lang.ref.Cleaner.Cleanable;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
/*[IF JAVA_SPEC_VERSION < 24]*/
import java.security.AccessController;
import java.security.PrivilegedAction;
/*[ENDIF] JAVA_SPEC_VERSION < 24 */

@SuppressWarnings("javadoc")
public class CleanerShutdown {

	public static void shutdownCleaner() {
		Cleaner commonCleaner = CleanerFactory.cleaner();
		CleanerImpl commonCleanerImpl = CleanerImpl.getCleanerImpl(commonCleaner);
		Cleanable ref = null;

		while ((ref = (Cleanable) commonCleanerImpl.queue.poll()) != null) {
			try {
				ref.clean();
			} catch (Throwable t) {
				/* do nothing */
			}
		}

		try {
			/*[IF JAVA_SPEC_VERSION >= 24]*/
			Method cleanableListReset = CleanerImpl.CleanableList.class.getDeclaredMethod("reset"); //$NON-NLS-1$
			cleanableListReset.setAccessible(true);
			cleanableListReset.invoke(commonCleanerImpl.activeList);
			/*[ELSE] JAVA_SPEC_VERSION >= 24 */
			Method phantomRemove = PhantomCleanable.class.getDeclaredMethod("remove"); //$NON-NLS-1$
			AccessController.doPrivileged((PrivilegedAction<Void>) () -> {
				phantomRemove.setAccessible(true);
				return null;
			});
			while (!commonCleanerImpl.phantomCleanableList.isListEmpty()) {
				phantomRemove.invoke(commonCleanerImpl.phantomCleanableList);
			}
			/*[ENDIF] JAVA_SPEC_VERSION >= 24 */
		} catch (NoSuchMethodException
				/*[IF JAVA_SPEC_VERSION < 24]*/
				| SecurityException
				/*[ENDIF] JAVA_SPEC_VERSION < 24 */
				| IllegalAccessException
				| IllegalArgumentException
				| InvocationTargetException e)
		{
			/* should not fail */
			e.printStackTrace();
		}
	}
}
